@@ -15,6 +15,7 @@ from ...const import (
     DateAndTime,
     NodeStatus,
     PowerLevel,
+    Protocols,
     SecurityClass,
 )
 from ...event import Event, EventBase
@@ -371,6 +372,13 @@ class Node(EventBase):
         """Return the default transition duration."""
         return self.data.get("defaultTransitionDuration")
 
+    @property
+    def protocol(self) -> Protocols | None:
+        """Return the protocol used to communicate with this node."""
+        if "protocol" in self.data:
+            return Protocols(self.data["protocol"])
+        return None
+
     def _update_endpoints(self, endpoints: list[EndpointDataType]) -> None:
         """Update the endpoints data."""
         new_endpoints_data = {endpoint["index"]: endpoint for endpoint in endpoints}
